==> testdisk_7.1.orig.tar.bz2: testdisk-7.1/src/lang/qphotorec.ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="518"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Выберите назначение для сохранения восстановленных файлов.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Выберите файл raw</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Файлы raw (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Системный=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No harddisk found</source>
        <translation>Жесткий диск не найден</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <translation>Жесткий диск не найден
Вы должны быть администратором, чтобы использовать эту программу.
Под win9x используйте DOS версию.
Под Vista или более поздней версии выберите эту программу, щелкните правой кнопкой мыши и выберите «Запустить от имени администратора».</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No harddisk found
You need to be root to use PhotoRec.</source>
        <translation>Жесткий диск не найден
Вы должны быть суперпользователем, чтобы использовать PhotoRec.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Нет диска!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="452"/>
        <source>Add a raw disk image...</source>
        <translation>Добавить образ raw диска...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="458"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec является свободным программным обеспечением и поставляется с БЕЗ ВСЯКИХ ГАРАНТИЙ.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="459"/>
        <source>Please select a media to recover from</source>
        <translation>Выберите носитель для восстановления из</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>Емкость диска должна быть правильно определена для успешного восстановления.
Если перечисленный выше диск имеет неправильный размер, проверьте установки перемычек для жестких дисков
и обнаружение BIOS, и установите последние обновления операционной системы и дисковых накопителей.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="469"/>
        <source>Flags</source>
        <translation>Флаги</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="470"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="471"/>
        <source>File System</source>
        <translation>Файловая система</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="488"/>
        <source>File System type</source>
        <translation>Тип файловой системы</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="489"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>Файловая система ext2/ext3/ext4</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="490"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>Файловая система FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="494"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Свободное: Сканирование файла только из незанятого пространства</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="495"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Весь: Извлечение файлов из всего раздела</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="522"/>
        <source>&amp;Browse</source>
        <translation>О&amp;бзор</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="538"/>
        <source>&amp;Search</source>
        <translation>&amp;Поиск</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="542"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Форматы файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="642"/>
        <source>Destination:</source>
        <translation>Назначение:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="647"/>
        <source>Recovery completed</source>
        <translation>Восстановление завершено</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="652"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Полный перебор %1 оставшихся секторов (тест %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="660"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Проход %1 - Чтение сектора %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="665"/>
        <source>%1/10 headers found</source>
        <translation>Найдено %1/10 заголовков</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="667"/>
        <source>%1 files found</source>
        <translation>Найдено %1 файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="540"/>
        <location filename="src/qphotorec.cpp" line="762"/>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="750"/>
        <source>File family</source>
        <translation>Семейство файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="751"/>
        <source>Number of files recovered</source>
        <translation>Количество восстановленных</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="834"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Не удалось создать файл!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="835"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Не удалось создать файл! Выберите другое назначение</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="854"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>PhotoRec: Не хватает места!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="855"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Там не осталось свободного места! Освободите место на диске или выберите другое место назначения</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="924"/>
        <source>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <translation>QPhotoRec является свободным программным обеспечением: вы можете распространять и / или изменять его в соответствии с условиями GNU General Public License, опубликованной Фондом свободного программного  обеспечения, либо лицензии версии 2, либо (по вашему выбору) любой более поздней версии.

PhotoRec распространяется в надежде, что она будет полезной, но БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ; даже без подразумеваевания гарантий КОММЕРЧЕСКОЙ ЦЕННОСТИ или ПРИГОДНОСТИ ДЛЯ КОНКРЕТНЫХ ЦЕЛЕЙ.  Смотрите GNU General Public License для более подробной информации.

Вы должны были получить копию GNU General Public License вместе с PhotoRec.  Если нет, смотрите &lt;http://www.gnu.org/licenses/&gt;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="925"/>
        <source>QPhotoRec: About</source>
        <translation>О программе QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="954"/>
        <source>File Formats</source>
        <translation>Форматы файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>&amp;Reset</source>
        <translation>Сб&amp;росить</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="958"/>
        <source>Res&amp;tore</source>
        <translation>&amp;Вернуть</translation>
    </message>
</context>
</TS>

==> testdisk_7.2.orig.tar.bz2: testdisk-7.2/src/lang/qphotorec.ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="521"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Выберите назначение для сохранения восстановленных файлов.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Выберите файл raw</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Файлы raw (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Системный=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No hard disk found</source>
        <oldsource>No harddisk found</oldsource>
        <translation>Жесткий диск не найден</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No hard disk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <oldsource>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</oldsource>
        <translation>Жесткий диск не найден
Вы должны быть администратором, чтобы использовать эту программу.
Под win9x используйте DOS версию.
Под Vista или более поздней версии выберите эту программу, щелкните правой кнопкой мыши и выберите «Запустить от имени администратора».</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No hard disk found
You need to be root to use PhotoRec.</source>
        <oldsource>No harddisk found
You need to be root to use PhotoRec.</oldsource>
        <translation>Жесткий диск не найден
Вы должны быть суперпользователем, чтобы использовать PhotoRec.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Нет диска!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="455"/>
        <source>Add a raw disk image...</source>
        <translation>Добавить образ raw диска...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="461"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec является свободным программным обеспечением и поставляется с БЕЗ ВСЯКИХ ГАРАНТИЙ.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Please select a media to recover from</source>
        <translation>Выберите носитель для восстановления из</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="465"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>Емкость диска должна быть правильно определена для успешного восстановления.
Если перечисленный выше диск имеет неправильный размер, проверьте установки перемычек для жестких дисков
и обнаружение BIOS, и установите последние обновления операционной системы и дисковых накопителей.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Flags</source>
        <translation>Флаги</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="474"/>
        <source>File System</source>
        <translation>Файловая система</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="475"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="476"/>
        <source>Label</source>
        <translation>Метка</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="491"/>
        <source>File System type</source>
        <translation>Тип файловой системы</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="492"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>Файловая система ext2/ext3/ext4</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="493"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>Файловая система FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="497"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Свободное: Сканирование файла только из незанятого пространства</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="498"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Весь: Извлечение файлов из всего раздела</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="525"/>
        <source>&amp;Browse</source>
        <translation>О&amp;бзор</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;Search</source>
        <translation>&amp;Поиск</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="544"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="545"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Форматы файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="645"/>
        <source>Destination:</source>
        <translation>Назначение:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="650"/>
        <source>Recovery completed</source>
        <translation>Восстановление завершено</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="655"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Полный перебор %1 оставшихся секторов (тест %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="663"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Проход %1 - Чтение сектора %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="668"/>
        <source>%1/10 headers found</source>
        <translation>Найдено %1/10 заголовков</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="670"/>
        <source>%1 files found</source>
        <translation>Найдено %1 файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="753"/>
        <source>File family</source>
        <translation>Семейство файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="543"/>
        <location filename="src/qphotorec.cpp" line="765"/>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="754"/>
        <source>Number of files recovered</source>
        <translation>Количество восстановленных</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="837"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Не удалось создать файл!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="838"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Не удалось создать файл! Выберите другое назначение</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="857"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>PhotoRec: Не хватает места!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="858"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Там не осталось свободного места! Освободите место на диске или выберите другое место назначения</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="927"/>
        <source>QPhotoRec is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <oldsource>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</oldsource>
        <translation>QPhotoRec является свободным программным обеспечением: вы можете распространять и / или изменять его в соответствии с условиями GNU General Public License, опубликованной Фондом свободного программного  обеспечения, либо лицензии версии 2, либо (по вашему выбору) любой более поздней версии.

PhotoRec распространяется в надежде, что она будет полезной, но БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ; даже без подразумеваевания гарантий КОММЕРЧЕСКОЙ ЦЕННОСТИ или ПРИГОДНОСТИ ДЛЯ КОНКРЕТНЫХ ЦЕЛЕЙ.  Смотрите GNU General Public License для более подробной информации.

Вы должны были получить копию GNU General Public License вместе с PhotoRec.  Если нет, смотрите &lt;http://www.gnu.org/licenses/&gt;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="928"/>
        <source>QPhotoRec: About</source>
        <translation>О программе QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>File Formats</source>
        <translation>Форматы файлов</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="960"/>
        <source>&amp;Reset</source>
        <translation>Сб&amp;росить</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="961"/>
        <source>Res&amp;tore</source>
        <translation>&amp;Вернуть</translation>
    </message>
</context>
</TS>
